pub enum ShaderDefVal {
Bool(String, bool),
Int(String, i32),
UInt(String, u32),
}Expand description
A compile time shader value definition to be inlined into the shader source. Variant tuples contain the name of the definition, and the value.
Variants
Implementations
Sourceimpl ShaderDefVal
impl ShaderDefVal
Sourcepub fn value_as_string(&self) -> String
pub fn value_as_string(&self) -> String
Returns the value of the define as a string.